#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-map
version:              0.4.0.0
visibility:           public
id:                   dependent-map-0.4.0.0-5OPXLfk46QQAGRjDLPVaam
key:                  dependent-map-0.4.0.0-5OPXLfk46QQAGRjDLPVaam
license:              LicenseRef-OtherLicense
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-map
synopsis:             Dependent finite maps (partial dependent products)
description:
    Provides a type called @DMap@ which generalizes
    @Data.Map.Map@, allowing keys to specify the type
    of value that can be associated with them.

category:             Data, Dependent Types
abi:                  8797822c6eaed2c2f842d6ecc24832c4
exposed:              True
exposed-modules:
    Data.Dependent.Map Data.Dependent.Map.Internal
    Data.Dependent.Map.Lens

hidden-modules:       Data.Dependent.Map.PtrEquality
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dependent-map-0.4.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dependent-map-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/dependent-map-0.4.0.0
hs-libraries:         HSdependent-map-0.4.0.0-5OPXLfk46QQAGRjDLPVaam
depends:
    base-4.14.2.0 constraints-extras-0.3.1.0-2LnlfO4CkU1CvXDwv6boYo
    containers-0.6.4.1 dependent-sum-0.7.1.0-K5Ubw1JI8oOA91k5GKnqt6

haddock-interfaces:
    /usr/share/doc/haskell-dependent-map/html/dependent-map.haddock

haddock-html:         /usr/share/doc/haskell-dependent-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

